[gtk+/wip/baedert/drawing: 81/306] fontbutton: Call the css node "fontbutton"



commit 307e7b74a6d74e2e07fe236c940bce1489e75e4c
Author: Timm Bäder <mail baedert org>
Date:   Thu May 4 09:36:22 2017 +0200

    fontbutton: Call the css node "fontbutton"
    
    Otherwise the default looks like a button inside a button.

 gtk/gtkbutton.c     |    2 +-
 gtk/gtkfontbutton.c |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/gtk/gtkbutton.c b/gtk/gtkbutton.c
index aefa8ea..e9ac07d 100644
--- a/gtk/gtkbutton.c
+++ b/gtk/gtkbutton.c
@@ -47,7 +47,7 @@
  *
  * Button-like widgets like #GtkToggleButton, #GtkMenuButton, #GtkVolumeButton,
  * #GtkLockButton, #GtkColorButton, #GtkFontButton or #GtkFileChooserButton use
- * style classes such as .toggle, .popup, .scale, .lock, .color, .font, .file
+ * style classes such as .toggle, .popup, .scale, .lock, .color, .file
  * to differentiate themselves from a plain GtkButton.
  */
 
diff --git a/gtk/gtkfontbutton.c b/gtk/gtkfontbutton.c
index c7e0ea7..10c73d7 100644
--- a/gtk/gtkfontbutton.c
+++ b/gtk/gtkfontbutton.c
@@ -58,7 +58,7 @@
  *
  * # CSS nodes
  *
  * GtkFontButton has a single CSS node with name button and style class .font.
  */
 
 
@@ -611,7 +611,7 @@ gtk_font_button_class_init (GtkFontButtonClass *klass)
                                                 g_cclosure_marshal_VOID__VOID,
                                                 G_TYPE_NONE, 0);
 
-  gtk_widget_class_set_css_name (widget_class, "button");
+  gtk_widget_class_set_css_name (widget_class, "fontbutton");
 }
 
 static void
@@ -58,7 +58,7 @@
  * # CSS nodes
  *
- * GtkFontButton has a single CSS node with name button and style class .font.
+ * GtkFontButton has a single CSS node with name fontbutton.
  */
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]